==> BlueGriffon-0.9.1-Linux-x86.tar.bz2: content/bluegriffon/dialogs/markupCleaner.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Nvu.
 *
 * The Initial Developer of the Original Code is
 * Linspire Inc..
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Daniel Glazman (glazman@disruptive-innovations.com), on behalf of Linspire Inc.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function Startup()
{
  GetUIElements();
//@line 42 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/dialogs/markupCleaner.js"
  CenterDialogOnOpener();
//@line 44 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/dialogs/markupCleaner.js"
}

function RunCleanup()
{
  return MarkupCleaner.runCleanup(ClearReport, IncreaseReport);
}

function IncreaseReport(report)
{
  var reportValue = Number(report.value) + 1;
  report.value = reportValue;
}

function ClearReport(report, checkbox)
{
  if (report)
    if (checkbox && checkbox.checked)
      report.setAttribute("value", "0");
    else
      report.setAttribute("value", " ");
}

==> BlueGriffon-1.1.1-Linux-x86.tar.bz2: content/bluegriffon/dialogs/markupCleaner.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Nvu.
 *
 * The Initial Developer of the Original Code is
 * Linspire Inc..
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Daniel Glazman (glazman@disruptive-innovations.com), on behalf of Linspire Inc.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function Startup()
{
  GetUIElements();
//@line 42 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/dialogs/markupCleaner.js"
  CenterDialogOnOpener();
//@line 44 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/dialogs/markupCleaner.js"
}

function RunCleanup()
{
  return MarkupCleaner.runCleanup(ClearReport, IncreaseReport);
}

function IncreaseReport(report)
{
  var reportValue = Number(report.value) + 1;
  report.value = reportValue;
}

function ClearReport(report, checkbox)
{
  if (report)
    if (checkbox && checkbox.checked)
      report.setAttribute("value", "0");
    else
      report.setAttribute("value", " ");
}
